@@ -33,10 +33,10 @@ class Domoticz(IPlugin):
 #
 	def switchlight(self, jsonInput):
 		bodies = ""
-		entity = jsonInput['outcome']['entities']['body']
+		entity = jsonInput['outcome']['entities']['value']
 		log.msg("entity :  %s" % (entity))		
-#		if jsonInput['outcome']['entities']['location']['body'] :
-#			location = jsonInput['outcome']['entities']['location']['body']
+#		if jsonInput['outcome']['entities']['location']['value'] :
+			location = jsonInput['outcome']['entities']['location']['body']
 #		else:
 #			bodies = "pas de lieu"
 #			location= "VIDE"
@@ -68,10 +68,10 @@ class Domoticz(IPlugin):
 
 	def devices(self, jsonInput):
 		bodies = ""
-		inten = jsonInput['outcome']['entities']['body']
- 		log.msg("inten :  %s" % (inten)
+		entity = jsonInput['outcome']['entities']['value']
+		log.msg("entity :  %s" % (entity))		
 		if jsonInput['outcome']['entities']['location']['body'] :
-			location = jsonInput['outcome']['entities']['location']['body']
+			location = jsonInput['outcome']['entities']['location']['value']
 		else:
 			bodies = "pas de lieu"
 			location= "VIDE"
